import React, { useState, useEffect } from 'react';
import { Form, Button, Table } from 'antd';
import { connect, useNavigate } from 'umi';
import AuditModal from './AuditModal';
import { PageContainer, ProCard } from '@ant-design/pro-components';

function Audit(props) {
  const { list = [], dispatch, loading } = props;
  let navigate = useNavigate();
  const [form] = Form.useForm();
  const [visible, setVisible] = useState({
    audit: false,
    auditNode: false,
  });
  const [tabActive, setTabActive] = useState('1');
  const columns = [
    {
      title: '审批流名称',
      dataIndex: ['list', 'name'],
    },
    {
      title: '操作',
      render: (item, index) => (
        <>
          <a
            onClick={() => {
              setCurrentNode(item);
            }}
          >
            编辑
          </a>
        </>
      ),
    },
  ];
  const handleAuditOk = (values) => {
    dispatch({
      type: 'flow/addAudit',
      payload: values,
      callback: () => {
        changeVisible('audit', false);
      },
    });
  };
  const changeVisible = (type, visible) => {
    setVisible({
      ...visible,
      [type]: visible,
    });
  };
  const setCurrentNode = (item) => {
    if (item?.list)
      localStorage.setItem('currentAudit', JSON.stringify(item.list));
    dispatch({
      type: 'flow/save',
      payload: {
        current: item.list,
      },
    });
    navigate('/flow/audit');
  };

  useEffect(() => {
    dispatch({
      type: 'flow/queryAuditList',
    });
  }, []);

  return (
    <PageContainer
      title={null}
      extra={[
        <Button
          key={1}
          onClick={() => changeVisible('audit', true)}
          type="primary"
        >
          新建流程
        </Button>,
      ]}
      tabActiveKey={tabActive}
      tabList={[
        { key: 1, tab: 'OA' },
        { key: 2, tab: 'BOM' },
      ]}
      onTabChange={setTabActive}
    >
      <ProCard>
        <Table
          loading={loading['flow/queryAuditList']}
          rowKey="id"
          dataSource={list}
          columns={columns}
        />
      </ProCard>

      <AuditModal
        loading={loading['flow/addAudit']}
        visible={visible.audit}
        onOk={handleAuditOk}
        onCancel={() => changeVisible('audit', false)}
      />
    </PageContainer>
  );
}
export default connect(({ flow, loading }) => ({
  userList: [],
  list: flow.auditList,
  loading: loading.effects,
}))(Audit);
